<?php
/**
 * IT Company Lite Theme Customizer
 *
 * @package IT Company Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function it_company_lite_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'it_company_lite_custom_controls' );

function it_company_lite_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; 
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'it_company_lite_customize_partial_blogname', 
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'it_company_lite_customize_partial_blogdescription', 
	));

	//add home page setting pannel
	$ITCompanyLiteParentPanel = new IT_Company_Lite_WP_Customize_Panel( $wp_customize, 'it_company_lite_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'VW Settings', 'it-company-lite' ),
		'priority' => 10,
	));

	$wp_customize->add_panel( $ITCompanyLiteParentPanel );

	$HomePageParentPanel = new IT_Company_Lite_WP_Customize_Panel( $wp_customize, 'it_company_lite_homepage_panel', array(
		'title' => __( 'Homepage Settings', 'it-company-lite' ),
		'panel' => 'it_company_lite_panel_id',
	));

	$wp_customize->add_panel( $HomePageParentPanel );

	//Topbar
	$wp_customize->add_section( 'it_company_lite_topbar', array(
    	'title'      => __( 'Topbar Settings', 'it-company-lite' ),
		'priority'   => null,
		'panel' => 'it_company_lite_homepage_panel'
	) );

   	// Header Background color
	$wp_customize->add_setting('it_company_lite_header_background_color', array(
		'default'           => '#ebebeb',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'it_company_lite_header_background_color', array(
		'label'    => __('Header Background Color', 'it-company-lite'),
		'section'  => 'header_image',
	)));

	$wp_customize->add_setting('it_company_lite_header_img_position',array(
	  'default' => 'center top',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_header_img_position',array(
		'type' => 'select',
		'label' => __('Header Image Position','it-company-lite'),
		'section' => 'header_image',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'it-company-lite' ),
			'center top'   => esc_html__( 'Top', 'it-company-lite' ),
			'right top'   => esc_html__( 'Top Right', 'it-company-lite' ),
			'left center'   => esc_html__( 'Left', 'it-company-lite' ),
			'center center'   => esc_html__( 'Center', 'it-company-lite' ),
			'right center'   => esc_html__( 'Right', 'it-company-lite' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'it-company-lite' ),
			'center bottom'   => esc_html__( 'Bottom', 'it-company-lite' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'it-company-lite' ),
		),
	));

	$wp_customize->add_setting( 'it_company_lite_topbar_hide_show',
       array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_topbar_hide_show',
       array(
      'label' => esc_html__( 'Show / Hide Topbar','it-company-lite' ),
      'section' => 'it_company_lite_topbar'
    )));

     $wp_customize->add_setting('it_company_lite_topbar_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_topbar_padding_top_bottom',array(
		'label'	=> __('Topbar Padding Top Bottom','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_topbar',
		'type'=> 'text'
	));

    //Sticky Header
	$wp_customize->add_setting( 'it_company_lite_sticky_header',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_sticky_header',array(
        'label' => esc_html__( 'Sticky Header','it-company-lite' ),
        'section' => 'it_company_lite_topbar'
    )));

    $wp_customize->add_setting('it_company_lite_sticky_header_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_sticky_header_padding',array(
		'label'	=> __('Sticky Header Padding','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_topbar',
		'type'=> 'text'
	));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial('it_company_lite_location', array( 
		'selector' => '#topbar span', 
		'render_callback' => 'it_company_lite_customize_partial_it_company_lite_location', 
	));

    $wp_customize->add_setting('it_company_lite_location_icon',array(
		'default'	=> 'fas fa-map-marker-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new IT_Company_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'it_company_lite_location_icon',array(
		'label'	=> __('Add Location Icon','it-company-lite'),
		'transport' => 'refresh',
		'section'	=> 'it_company_lite_topbar',
		'setting'	=> 'it_company_lite_location_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('it_company_lite_location',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('it_company_lite_location',array(
		'label'	=> __('Add Location','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '123 Dummy Stret, USA', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_email_icon',array(
		'default'	=> 'fas fa-envelope-open',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new IT_Company_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'it_company_lite_email_icon',array(
		'label'	=> __('Add Email Icon','it-company-lite'),
		'transport' => 'refresh',
		'section'	=> 'it_company_lite_topbar',
		'setting'	=> 'it_company_lite_email_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('it_company_lite_email_address',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_email'
	));	
	$wp_customize->add_control('it_company_lite_email_address',array(
		'label'	=> __('Add Email Address','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'support@example.com', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_inquiry_btn_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('it_company_lite_inquiry_btn_text',array(
		'label'	=> __('Add Button Text','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'INQUIRY', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_inquiry_btn_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('it_company_lite_inquiry_btn_link',array(
		'label'	=> __('Add Button Link','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'https://example.com', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_phone',array(
		'default'=> '',
		'sanitize_callback'	=> 'it_company_lite_sanitize_phone_number'
	));	
	$wp_customize->add_control('it_company_lite_phone',array(
		'label'	=> __('Add Phone no.','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '+00 123 456 7890', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_topbar',
		'type'=> 'text'
	));

	//Menus Settings
	$wp_customize->add_section( 'it_company_lite_menu_section' , array(
    	'title' => __( 'Menus Settings', 'it-company-lite' ),
		'panel' => 'it_company_lite_homepage_panel'
	) );

	$wp_customize->add_setting('it_company_lite_navigation_menu_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_navigation_menu_font_size',array(
		'label'	=> __('Menus Font Size','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_menu_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_navigation_menu_font_weight',array(
        'default' => 700,
        'transport' => 'refresh',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_navigation_menu_font_weight',array(
        'type' => 'select',
        'label' => __('Menus Font Weight','it-company-lite'),
        'section' => 'it_company_lite_menu_section',
        'choices' => array(
        	'100' => __('100','it-company-lite'),
            '200' => __('200','it-company-lite'),
            '300' => __('300','it-company-lite'),
            '400' => __('400','it-company-lite'),
            '500' => __('500','it-company-lite'),
            '600' => __('600','it-company-lite'),
            '700' => __('700','it-company-lite'),
            '800' => __('800','it-company-lite'),
            '900' => __('900','it-company-lite'),
        ),
	) );

	// text trasform
	$wp_customize->add_setting('it_company_lite_menu_text_transform',array(
		'default'=> 'Capitalize',
		'sanitize_callback'	=> 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_menu_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Menus Text Transform','it-company-lite'),
		'choices' => array(
            'Uppercase' => __('Uppercase','it-company-lite'),
            'Capitalize' => __('Capitalize','it-company-lite'),
            'Lowercase' => __('Lowercase','it-company-lite'),
        ),
		'section'=> 'it_company_lite_menu_section',
	));

	$wp_customize->add_setting('it_company_lite_menus_item_style',array(
        'default' => '',
        'transport' => 'refresh',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_menus_item_style',array(
        'type' => 'select',
        'section' => 'it_company_lite_menu_section',
		'label' => __('Menu Item Hover Style','it-company-lite'),
		'choices' => array(
            'None' => __('None','it-company-lite'),
            'Zoom In' => __('Zoom In','it-company-lite'),
        ),
	) );

	$wp_customize->add_setting('it_company_lite_header_menus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'it_company_lite_header_menus_color', array(
		'label'    => __('Menus Color', 'it-company-lite'),
		'section'  => 'it_company_lite_menu_section',
	)));

	$wp_customize->add_setting('it_company_lite_header_menus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'it_company_lite_header_menus_hover_color', array(
		'label'    => __('Menus Hover Color', 'it-company-lite'),
		'section'  => 'it_company_lite_menu_section',
	)));

	$wp_customize->add_setting('it_company_lite_header_submenus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'it_company_lite_header_submenus_color', array(
		'label'    => __('Sub Menus Color', 'it-company-lite'),
		'section'  => 'it_company_lite_menu_section',
	)));

	$wp_customize->add_setting('it_company_lite_header_submenus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'it_company_lite_header_submenus_hover_color', array(
		'label'    => __('Sub Menus Hover Color', 'it-company-lite'),
		'section'  => 'it_company_lite_menu_section',
	)));

	//Social links
	$wp_customize->add_section(
		'it_company_lite_social_links', array(
			'title'		=>	__('Social Links', 'it-company-lite'),
			'priority'	=>	null,
			'panel'		=>	'it_company_lite_homepage_panel'
		));

	$wp_customize->add_setting('it_company_lite_social_icons',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_social_icons',array(
		'label' =>  __('Steps to setup social icons','it-company-lite'),
		'description' => __('<p>1. Go to Dashboard >> Appearance >> Widgets</p>
			<p>2. Add Vw Social Icon Widget in Social Widget area.</p>
			<p>3. Add social icons url and save.</p>','it-company-lite'),
		'section'=> 'it_company_lite_social_links',
		'type'=> 'hidden'
	));
	$wp_customize->add_setting('it_company_lite_social_icon_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_social_icon_btn',array(
		'description' => "<a target='_blank' href='". admin_url('widgets.php') ." '>Setup Social Icons</a>",
		'section'=> 'it_company_lite_social_links',
		'type'=> 'hidden'
	));
    
	//Slider
	$wp_customize->add_section( 'it_company_lite_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'it-company-lite' ),
    	'description' => __('Free theme has 3 slides options, For unlimited slides and more options </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/it-company-wordpress-theme/">GET PRO</a>','it-company-lite'),
		'priority'   => null,
		'panel' => 'it_company_lite_homepage_panel'
	) );

	$wp_customize->add_setting( 'it_company_lite_slider_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','it-company-lite' ),
      'section' => 'it_company_lite_slidersettings'
    )));

    $wp_customize->add_setting('it_company_lite_slider_type',array(
        'default' => 'Default slider',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	) );
	$wp_customize->add_control('it_company_lite_slider_type', array(
        'type' => 'select',
        'label' => __('Slider Type','it-company-lite'),
        'section' => 'it_company_lite_slidersettings',
        'choices' => array(
            'Default slider' => __('Default slider','it-company-lite'),
            'Advance slider' => __('Advance slider','it-company-lite'),
        ),
	));

	$wp_customize->add_setting('it_company_lite_advance_slider_shortcode',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_advance_slider_shortcode',array(
		'label'	=> __('Add Slider Shortcode','it-company-lite'),
		'section'=> 'it_company_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'it_company_lite_advance_slider'
	));

    //Selective Refresh
    $wp_customize->selective_refresh->add_partial('it_company_lite_slider_hide_show',array(
		'selector'        => '#slider .inner_carousel h1',
		'render_callback' => 'it_company_lite_customize_partial_it_company_lite_slider_hide_show',
	));

	for ( $count = 1; $count <= 3; $count++ ) {
		$wp_customize->add_setting( 'it_company_lite_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'it_company_lite_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'it_company_lite_slider_page' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'it-company-lite' ),
			'description' => __('Slider image size (1500 x 590)','it-company-lite'),
			'section'  => 'it_company_lite_slidersettings',
			'type'     => 'dropdown-pages',
			'active_callback' => 'it_company_lite_default_slider'
		) );
	}

	$wp_customize->add_setting('it_company_lite_slider_button_text',array(
		'default'=> 'Read More',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_slider_button_text',array(
		'label'	=> __('Add Slider Button Text','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Read More', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'it_company_lite_default_slider'
	));

	$wp_customize->add_setting('it_company_lite_slider_button_link',array(
        'default'=> '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('it_company_lite_slider_button_link',array(
        'label' => esc_html__('Add Button Link','it-company-lite'),
        'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example-info.com', 'it-company-lite' ),
        ),
        'section'=> 'it_company_lite_slidersettings',
        'type'=> 'url'
    ));

	//content layout
	$wp_customize->add_setting('it_company_lite_slider_content_option',array(
        'default' => 'Center',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control(new IT_Company_Lite_Image_Radio_Control($wp_customize, 'it_company_lite_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','it-company-lite'),
        'section' => 'it_company_lite_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/assets/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/assets/images/slider-content3.png',
    ),'active_callback' => 'it_company_lite_default_slider'
    )));

    //Slider content padding
    $wp_customize->add_setting('it_company_lite_slider_content_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_slider_content_padding_top_bottom',array(
		'label'	=> __('Slider Content Padding Top Bottom','it-company-lite'),
		'description'	=> __('Enter a value in %. Example:20%','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '50%', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'it_company_lite_default_slider'
	));

	$wp_customize->add_setting('it_company_lite_slider_content_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_slider_content_padding_left_right',array(
		'label'	=> __('Slider Content Padding Left Right','it-company-lite'),
		'description'	=> __('Enter a value in %. Example:20%','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '50%', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'it_company_lite_default_slider'
	));

    //Slider excerpt
	$wp_customize->add_setting( 'it_company_lite_slider_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'it_company_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'it_company_lite_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','it-company-lite' ),
		'section'     => 'it_company_lite_slidersettings',
		'type'        => 'range',
		'settings'    => 'it_company_lite_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),'active_callback' => 'it_company_lite_default_slider'
	) );

	//Slider height
	$wp_customize->add_setting('it_company_lite_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_slider_height',array(
		'label'	=> __('Slider Height','it-company-lite'),
		'description'	=> __('Specify the slider height (px).','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'it_company_lite_default_slider'
	));

	$wp_customize->add_setting( 'it_company_lite_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'it_company_lite_sanitize_float'
	) );
	$wp_customize->add_control( 'it_company_lite_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','it-company-lite'),
		'section' => 'it_company_lite_slidersettings',
		'type'  => 'number',
		'active_callback' => 'it_company_lite_default_slider'
	) );

	//Opacity
	$wp_customize->add_setting('it_company_lite_slider_opacity_color',array(
      'default'              => 0.4,
      'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));

	$wp_customize->add_control( 'it_company_lite_slider_opacity_color', array(
		'label'       => esc_html__( 'Slider Image Opacity','it-company-lite' ),
		'section'     => 'it_company_lite_slidersettings',
		'type'        => 'select',
		'settings'    => 'it_company_lite_slider_opacity_color',
		'choices' => array(
	      '0' =>  esc_attr('0','it-company-lite'),
	      '0.1' =>  esc_attr('0.1','it-company-lite'),
	      '0.2' =>  esc_attr('0.2','it-company-lite'),
	      '0.3' =>  esc_attr('0.3','it-company-lite'),
	      '0.4' =>  esc_attr('0.4','it-company-lite'),
	      '0.5' =>  esc_attr('0.5','it-company-lite'),
	      '0.6' =>  esc_attr('0.6','it-company-lite'),
	      '0.7' =>  esc_attr('0.7','it-company-lite'),
	      '0.8' =>  esc_attr('0.8','it-company-lite'),
	      '0.9' =>  esc_attr('0.9','it-company-lite')
	),'active_callback' => 'it_company_lite_default_slider'
	));

	$wp_customize->add_setting( 'it_company_lite_slider_image_overlay',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_slider_image_overlay',array(
      	'label' => esc_html__( 'Show / Hide Slider Image Overlay','it-company-lite' ),
      	'section' => 'it_company_lite_slidersettings',
      	'active_callback' => 'it_company_lite_default_slider'
    )));

    $wp_customize->add_setting('it_company_lite_slider_image_overlay_color', array(
		'default'           => '#927ae9',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'it_company_lite_slider_image_overlay_color', array(
		'label'    => __('Slider Image Overlay Color', 'it-company-lite'),
		'section'  => 'it_company_lite_slidersettings',
		'active_callback' => 'it_company_lite_default_slider'
	)));

	//About Section
	$wp_customize->add_section( 'it_company_lite_about_section' , array(
    	'title'      => __( 'About us', 'it-company-lite' ),
    	'description' => __('For more options of the about section </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/it-company-wordpress-theme/">GET PRO</a>','it-company-lite'),
		'priority'   => null,
		'panel' => 'it_company_lite_homepage_panel'
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'it_company_lite_section_main_title', array( 
		'selector' => '#about h2', 
		'render_callback' => 'it_company_lite_customize_partial_it_company_lite_section_main_title',
	));

	$wp_customize->add_setting('it_company_lite_section_main_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('it_company_lite_section_main_title',array(
		'label'	=> __('Section Title','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'ABOUT US', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_about_section',
		'setting'=> 'it_company_lite_section_main_title',
		'type'=> 'text'
	));	

	$wp_customize->add_setting('it_company_lite_section_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('it_company_lite_section_text',array(
		'label'	=> __('Section Text Line','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit.', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_about_section',
		'setting'=> 'it_company_lite_section_text',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'it_company_lite_about_page', array(
		'default'           => '',
		'sanitize_callback' => 'it_company_lite_sanitize_dropdown_pages'
	) );
	$wp_customize->add_control( 'it_company_lite_about_page', array(
		'label'    => __( 'About Page', 'it-company-lite' ),
		'section'  => 'it_company_lite_about_section',
		'type'     => 'dropdown-pages'
	) );

	//About excerpt
	$wp_customize->add_setting( 'it_company_lite_about_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'it_company_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'it_company_lite_about_excerpt_number', array(
		'label'       => esc_html__( 'About Excerpt length','it-company-lite' ),
		'section'     => 'it_company_lite_about_section',
		'type'        => 'range',
		'settings'    => 'it_company_lite_about_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('it_company_lite_about_button_text',array(
		'default'=> 'CONTINUE READING',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_about_button_text',array(
		'label'	=> __('Add About Button Text','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'CONTINUE READING', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_about_section',
		'type'=> 'text'
	));

	//Work Section
	$wp_customize->add_section('it_company_lite_work', array(
		'title'       => __('Work Section', 'it-company-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','it-company-lite'),
		'priority'    => null,
		'panel'       => 'it_company_lite_homepage_panel',
	));

	$wp_customize->add_setting('it_company_lite_work_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_work_text',array(
		'description' => __('<p>1. More options for work section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for work section.</p>','it-company-lite'),
		'section'=> 'it_company_lite_work',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('it_company_lite_work_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_work_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=it_company_lite_guide') ." '>More Info</a>",
		'section'=> 'it_company_lite_work',
		'type'=> 'hidden'
	));

	//Projects Section
	$wp_customize->add_section('it_company_lite_projects', array(
		'title'       => __('Projects Section', 'it-company-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','it-company-lite'),
		'priority'    => null,
		'panel'       => 'it_company_lite_homepage_panel',
	));

	$wp_customize->add_setting('it_company_lite_projects_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_projects_text',array(
		'description' => __('<p>1. More options for projects section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for projects section.</p>','it-company-lite'),
		'section'=> 'it_company_lite_projects',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('it_company_lite_projects_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_projects_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=it_company_lite_guide') ." '>More Info</a>",
		'section'=> 'it_company_lite_projects',
		'type'=> 'hidden'
	));

	//Steps Section
	$wp_customize->add_section('it_company_lite_steps', array(
		'title'       => __('Steps Section', 'it-company-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','it-company-lite'),
		'priority'    => null,
		'panel'       => 'it_company_lite_homepage_panel',
	));

	$wp_customize->add_setting('it_company_lite_steps_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_steps_text',array(
		'description' => __('<p>1. More options for steps section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for steps section.</p>','it-company-lite'),
		'section'=> 'it_company_lite_steps',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('it_company_lite_steps_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_steps_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=it_company_lite_guide') ." '>More Info</a>",
		'section'=> 'it_company_lite_steps',
		'type'=> 'hidden'
	));

	//team Section
	$wp_customize->add_section('it_company_lite_team', array(
		'title'       => __('Team Section', 'it-company-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','it-company-lite'),
		'priority'    => null,
		'panel'       => 'it_company_lite_homepage_panel',
	));

	$wp_customize->add_setting('it_company_lite_team_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_team_text',array(
		'description' => __('<p>1. More options for team section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for team section.</p>','it-company-lite'),
		'section'=> 'it_company_lite_team',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('it_company_lite_team_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_team_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=it_company_lite_guide') ." '>More Info</a>",
		'section'=> 'it_company_lite_team',
		'type'=> 'hidden'
	));

	//Testimonials Section
	$wp_customize->add_section('it_company_lite_testimonials', array(
		'title'       => __('Testimonials Section', 'it-company-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','it-company-lite'),
		'priority'    => null,
		'panel'       => 'it_company_lite_homepage_panel',
	));

	$wp_customize->add_setting('it_company_lite_testimonials_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_testimonials_text',array(
		'description' => __('<p>1. More options for testimonials section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for testimonials section.</p>','it-company-lite'),
		'section'=> 'it_company_lite_testimonials',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('it_company_lite_testimonials_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_testimonials_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=it_company_lite_guide') ." '>More Info</a>",
		'section'=> 'it_company_lite_testimonials',
		'type'=> 'hidden'
	));

	//plans pricing Section
	$wp_customize->add_section('it_company_lite_plans_pricing', array(
		'title'       => __('Plans Pricing Section', 'it-company-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','it-company-lite'),
		'priority'    => null,
		'panel'       => 'it_company_lite_homepage_panel',
	));

	$wp_customize->add_setting('it_company_lite_plans_pricing_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_plans_pricing_text',array(
		'description' => __('<p>1. More options for plans pricing section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for plans pricing section.</p>','it-company-lite'),
		'section'=> 'it_company_lite_plans_pricing',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('it_company_lite_plans_pricing_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_plans_pricing_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=it_company_lite_guide') ." '>More Info</a>",
		'section'=> 'it_company_lite_plans_pricing',
		'type'=> 'hidden'
	));

	//records Section
	$wp_customize->add_section('it_company_lite_records', array(
		'title'       => __('Records Section', 'it-company-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','it-company-lite'),
		'priority'    => null,
		'panel'       => 'it_company_lite_homepage_panel',
	));

	$wp_customize->add_setting('it_company_lite_records_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_records_text',array(
		'description' => __('<p>1. More options for records section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for records section.</p>','it-company-lite'),
		'section'=> 'it_company_lite_records',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('it_company_lite_records_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_records_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=it_company_lite_guide') ." '>More Info</a>",
		'section'=> 'it_company_lite_records',
		'type'=> 'hidden'
	));

	//partners Section
	$wp_customize->add_section('it_company_lite_partners', array(
		'title'       => __('Partners Section', 'it-company-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','it-company-lite'),
		'priority'    => null,
		'panel'       => 'it_company_lite_homepage_panel',
	));

	$wp_customize->add_setting('it_company_lite_partners_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_partners_text',array(
		'description' => __('<p>1. More options for partners section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for partners section.</p>','it-company-lite'),
		'section'=> 'it_company_lite_partners',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('it_company_lite_partners_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_partners_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=it_company_lite_guide') ." '>More Info</a>",
		'section'=> 'it_company_lite_partners',
		'type'=> 'hidden'
	));

	//contact us Section
	$wp_customize->add_section('it_company_lite_contact_us', array(
		'title'       => __('Contact Us Section', 'it-company-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','it-company-lite'),
		'priority'    => null,
		'panel'       => 'it_company_lite_homepage_panel',
	));

	$wp_customize->add_setting('it_company_lite_contact_us_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_contact_us_text',array(
		'description' => __('<p>1. More options for contact us section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for contact us section.</p>','it-company-lite'),
		'section'=> 'it_company_lite_contact_us',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('it_company_lite_contact_us_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_contact_us_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=it_company_lite_guide') ." '>More Info</a>",
		'section'=> 'it_company_lite_contact_us',
		'type'=> 'hidden'
	));

	//latest post Section
	$wp_customize->add_section('it_company_lite_latest_post', array(
		'title'       => __('Latest Post Section', 'it-company-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','it-company-lite'),
		'priority'    => null,
		'panel'       => 'it_company_lite_homepage_panel',
	));

	$wp_customize->add_setting('it_company_lite_latest_post_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_latest_post_text',array(
		'description' => __('<p>1. More options for latest post section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for latest post section.</p>','it-company-lite'),
		'section'=> 'it_company_lite_latest_post',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('it_company_lite_latest_post_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_latest_post_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=it_company_lite_guide') ." '>More Info</a>",
		'section'=> 'it_company_lite_latest_post',
		'type'=> 'hidden'
	));

	//Footer Text
	$wp_customize->add_section('it_company_lite_footer',array(
		'title'	=> __('Footer','it-company-lite'),
		'description' => __('For more options of the footer section </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/it-company-wordpress-theme/">GET PRO</a>','it-company-lite'),
		'panel' => 'it_company_lite_homepage_panel',
	));	

	$wp_customize->add_setting( 'it_company_lite_footer_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_footer_hide_show',array(
      'label' => esc_html__( 'Show / Hide Footer','it-company-lite' ),
      'section' => 'it_company_lite_footer'
    )));

 	// font size
	$wp_customize->add_setting('it_company_lite_button_footer_font_size',array(
		'default'=> 25,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_button_footer_font_size',array(
		'label'	=> __('Footer Heading Font Size','it-company-lite'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'it_company_lite_footer',
	));

	$wp_customize->add_setting('it_company_lite_button_footer_heading_letter_spacing',array(
		'default'=> 1,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_button_footer_heading_letter_spacing',array(
		'label'	=> __('Heading Letter Spacing','it-company-lite'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
	),
		'section'=> 'it_company_lite_footer',
	));

	// text trasform
	$wp_customize->add_setting('it_company_lite_button_footer_text_transform',array(
		'default'=> 'Capitalize',
		'sanitize_callback'	=> 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_button_footer_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Heading Text Transform','it-company-lite'),
		'choices' => array(
      'Uppercase' => __('Uppercase','it-company-lite'),
      'Capitalize' => __('Capitalize','it-company-lite'),
      'Lowercase' => __('Lowercase','it-company-lite'),
    ),
		'section'=> 'it_company_lite_footer',
	));

	$wp_customize->add_setting('it_company_lite_footer_heading_weight',array(
        'default' => '',
        'transport' => 'refresh',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_footer_heading_weight',array(
        'type' => 'select',
        'label' => __('Heading Font Weight','it-company-lite'),
        'section' => 'it_company_lite_footer',
        'choices' => array(
        	'100' => __('100','it-company-lite'),
            '200' => __('200','it-company-lite'),
            '300' => __('300','it-company-lite'),
            '400' => __('400','it-company-lite'),
            '500' => __('500','it-company-lite'),
            '600' => __('600','it-company-lite'),
            '700' => __('700','it-company-lite'),
            '800' => __('800','it-company-lite'),
            '900' => __('900','it-company-lite'),
        ),
	) );

  	$wp_customize->add_setting('it_company_lite_footer_template',array(
	    'default'	=> esc_html('it-company-lite-footer-one'),
	    'sanitize_callback'	=> 'it_company_lite_sanitize_choices'
  	));
 	$wp_customize->add_control('it_company_lite_footer_template',array(
        'label'	=> esc_html__('Footer style','it-company-lite'),
        'section'	=> 'it_company_lite_footer',
        'setting'	=> 'it_company_lite_footer_template',
        'type' => 'select',
        'choices' => array(
            'it-company-lite-footer-one' => esc_html__('Style 1', 'it-company-lite'),
            'it-company-lite-footer-two' => esc_html__('Style 2', 'it-company-lite'),
            'it-company-lite-footer-three' => esc_html__('Style 3', 'it-company-lite'),
            'it-company-lite-footer-four' => esc_html__('Style 4', 'it-company-lite'),
            'it-company-lite-footer-five' => esc_html__('Style 5', 'it-company-lite'),
        )
  	));

	$wp_customize->add_setting('it_company_lite_footer_background_color', array(
		'default'           => '#344151',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'it_company_lite_footer_background_color', array(
		'label'    => __('Footer Background Color', 'it-company-lite'),
		'section'  => 'it_company_lite_footer',
	)));

	$wp_customize->add_setting('it_company_lite_footer_background_image',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'it_company_lite_footer_background_image',array(
        'label' => __('Footer Background Image','it-company-lite'),
        'section' => 'it_company_lite_footer'
	)));

	$wp_customize->add_setting('it_company_lite_footer_img_position',array(
	  'default' => 'center center',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_footer_img_position',array(
		'type' => 'select',
		'label' => __('Footer Image Position','it-company-lite'),
		'section' => 'it_company_lite_footer',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'it-company-lite' ),
			'center top'   => esc_html__( 'Top', 'it-company-lite' ),
			'right top'   => esc_html__( 'Top Right', 'it-company-lite' ),
			'left center'   => esc_html__( 'Left', 'it-company-lite' ),
			'center center'   => esc_html__( 'Center', 'it-company-lite' ),
			'right center'   => esc_html__( 'Right', 'it-company-lite' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'it-company-lite' ),
			'center bottom'   => esc_html__( 'Bottom', 'it-company-lite' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'it-company-lite' ),
		),
	));

	// Footer
	$wp_customize->add_setting('it_company_lite_img_footer',array(
		'default'=> 'scroll',
		'sanitize_callback'	=> 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_img_footer',array(
		'type' => 'select',
		'label'	=> __('Footer Background Attatchment','it-company-lite'),
		'choices' => array(
            'fixed' => __('fixed','it-company-lite'),
            'scroll' => __('scroll','it-company-lite'),
        ),
		'section'=> 'it_company_lite_footer',
	));

	$wp_customize->add_setting('it_company_lite_footer_widgets_heading',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_footer_widgets_heading',array(
        'type' => 'select',
        'label' => __('Footer Widget Heading','it-company-lite'),
        'section' => 'it_company_lite_footer',
        'choices' => array(
        	'Left' => __('Left','it-company-lite'),
            'Center' => __('Center','it-company-lite'),
            'Right' => __('Right','it-company-lite')
        ),
	) );

	$wp_customize->add_setting('it_company_lite_footer_widgets_content',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_footer_widgets_content',array(
        'type' => 'select',
        'label' => __('Footer Widget Content','it-company-lite'),
        'section' => 'it_company_lite_footer',
        'choices' => array(
        	'Left' => __('Left','it-company-lite'),
            'Center' => __('Center','it-company-lite'),
            'Right' => __('Right','it-company-lite')
        ),
	) );

	// footer padding
	$wp_customize->add_setting('it_company_lite_footer_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_footer_padding',array(
		'label'	=> __('Footer Top Bottom Padding','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'it-company-lite' ),
    ),
		'section'=> 'it_company_lite_footer',
		'type'=> 'text'
	));

    // footer social icon
  	$wp_customize->add_setting( 'it_company_lite_footer_icon',array(
		'default' => false,
		'transport' => 'refresh',
		'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
  	$wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_footer_icon',array(
		'label' => esc_html__( 'Show / Hide Footer Social Icon','it-company-lite' ),
		'section' => 'it_company_lite_footer'
    )));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('it_company_lite_footer_text', array( 
		'selector' => '.copyright p', 
		'render_callback' => 'it_company_lite_customize_partial_it_company_lite_footer_text', 
	));

	$wp_customize->add_setting( 'it_company_lite_copyright_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_copyright_hide_show',array(
      'label' => esc_html__( 'Show / Hide Copyright','it-company-lite' ),
      'section' => 'it_company_lite_footer'
    )));

	$wp_customize->add_setting('it_company_lite_copyright_background_color', array(
		'default'           => '#927ae9',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'it_company_lite_copyright_background_color', array(
		'label'    => __('Copyright Background Color', 'it-company-lite'),
		'section'  => 'it_company_lite_footer',
	)));
	
	$wp_customize->add_setting('it_company_lite_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('it_company_lite_footer_text',array(
		'label'	=> __('Copyright Text','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2018, .....', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_footer',
		'setting'=> 'it_company_lite_footer_text',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_copyright_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_copyright_font_size',array(
		'label'	=> __('Copyright Font Size','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_footer',
		'type'=> 'text'
	));	

	$wp_customize->add_setting('it_company_lite_copyright_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_copyright_padding_top_bottom',array(
		'label'	=> __('Copyright Padding Top Bottom','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_copyright_alignment',array(
        'default' => 'center',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control(new IT_Company_Lite_Image_Radio_Control($wp_customize, 'it_company_lite_copyright_alignment', array(
        'type' => 'select',
        'label' => __('Copyright Alignment','it-company-lite'),
        'section' => 'it_company_lite_footer',
        'settings' => 'it_company_lite_copyright_alignment',
        'choices' => array(
            'left' => get_template_directory_uri().'/assets/images/copyright1.png',
            'center' => get_template_directory_uri().'/assets/images/copyright2.png',
            'right' => get_template_directory_uri().'/assets/images/copyright3.png'
    ))));

	$wp_customize->add_setting( 'it_company_lite_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','it-company-lite' ),
      	'section' => 'it_company_lite_footer'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial('it_company_lite_scroll_to_top_icon', array( 
		'selector' => '.scrollup i', 
		'render_callback' => 'it_company_lite_customize_partial_it_company_lite_scroll_to_top_icon', 
	));

    $wp_customize->add_setting('it_company_lite_scroll_to_top_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new IT_Company_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'it_company_lite_scroll_to_top_icon',array(
		'label'	=> __('Add Scroll to Top Icon','it-company-lite'),
		'transport' => 'refresh',
		'section'	=> 'it_company_lite_footer',
		'setting'	=> 'it_company_lite_scroll_to_top_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('it_company_lite_scroll_to_top_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_scroll_to_top_font_size',array(
		'label'	=> __('Icon Font Size','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_scroll_to_top_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_scroll_to_top_padding',array(
		'label'	=> __('Icon Top Bottom Padding','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_scroll_to_top_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_scroll_to_top_width',array(
		'label'	=> __('Icon Width','it-company-lite'),
		'description'	=> __('Enter a value in pixels Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_scroll_to_top_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_scroll_to_top_height',array(
		'label'	=> __('Icon Height','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'it_company_lite_scroll_to_top_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'it_company_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'it_company_lite_scroll_to_top_border_radius', array(
		'label'       => esc_html__( 'Icon Border Radius','it-company-lite' ),
		'section'     => 'it_company_lite_footer',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('it_company_lite_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control(new IT_Company_Lite_Image_Radio_Control($wp_customize, 'it_company_lite_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','it-company-lite'),
        'section' => 'it_company_lite_footer',
        'settings' => 'it_company_lite_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/layout2.png',
            'Right' => get_template_directory_uri().'/assets/images/layout3.png'
    ))));

	//Blog Post
	$wp_customize->add_panel( $ITCompanyLiteParentPanel );

	$BlogPostParentPanel = new IT_Company_Lite_WP_Customize_Panel( $wp_customize, 'blog_post_parent_panel', array(
		'title' => __( 'Blog Post Settings', 'it-company-lite' ),
		'panel' => 'it_company_lite_panel_id',
	));

	$wp_customize->add_panel( $BlogPostParentPanel );

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'it_company_lite_post_settings', array(
		'title' => __( 'Post Settings', 'it-company-lite' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Blog layout
    $wp_customize->add_setting('it_company_lite_blog_layout_option',array(
        'default' => 'Default',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
    ));
    $wp_customize->add_control(new IT_Company_Lite_Image_Radio_Control($wp_customize, 'it_company_lite_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Layouts','it-company-lite'),
        'section' => 'it_company_lite_post_settings',
        'choices' => array(
            'Default' => get_template_directory_uri().'/assets/images/blog-layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/blog-layout2.png',
            'Left' => get_template_directory_uri().'/assets/images/blog-layout3.png',
    ))));

   	// Add Settings and Controls for Layout
	$wp_customize->add_setting('it_company_lite_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'	        
	) );
	$wp_customize->add_control('it_company_lite_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','it-company-lite'),
        'description' => __('Here you can change the sidebar layout for posts. ','it-company-lite'),
        'section' => 'it_company_lite_post_settings',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','it-company-lite'),
            'Right Sidebar' => __('Right Sidebar','it-company-lite'),
            'One Column' => __('One Column','it-company-lite'),
            'Three Columns' => __('Three Columns','it-company-lite'),
            'Four Columns' => __('Four Columns','it-company-lite'),
            'Grid Layout' => __('Grid Layout','it-company-lite')
        ),
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('it_company_lite_toggle_postdate', array( 
		'selector' => '.post-main-box h2 a', 
		'render_callback' => 'it_company_lite_customize_partial_it_company_lite_toggle_postdate', 
	));

  	$wp_customize->add_setting('it_company_lite_toggle_postdate_icon',array(
		'default'	=> 'fas fa-calendar',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new IT_Company_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'it_company_lite_toggle_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','it-company-lite'),
		'transport' => 'refresh',
		'section'	=> 'it_company_lite_post_settings',
		'setting'	=> 'it_company_lite_toggle_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'it_company_lite_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_toggle_postdate',array(
        'label' => esc_html__( 'Show / Hide Post Date','it-company-lite' ),
        'section' => 'it_company_lite_post_settings'
    )));

    $wp_customize->add_setting('it_company_lite_toggle_author_icon',array(
		'default'	=> 'far fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new IT_Company_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'it_company_lite_toggle_author_icon',array(
		'label'	=> __('Add Author Icon','it-company-lite'),
		'transport' => 'refresh',
		'section'	=> 'it_company_lite_post_settings',
		'setting'	=> 'it_company_lite_toggle_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'it_company_lite_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_toggle_author',array(
		'label' => esc_html__( 'Show / Hide Author','it-company-lite' ),
		'section' => 'it_company_lite_post_settings'
    )));

    $wp_customize->add_setting('it_company_lite_toggle_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new IT_Company_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'it_company_lite_toggle_comments_icon',array(
		'label'	=> __('Add Comments Icon','it-company-lite'),
		'transport' => 'refresh',
		'section'	=> 'it_company_lite_post_settings',
		'setting'	=> 'it_company_lite_toggle_comments_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'it_company_lite_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_toggle_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','it-company-lite' ),
		'section' => 'it_company_lite_post_settings'
    )));

    $wp_customize->add_setting('it_company_lite_toggle_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new IT_Company_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'it_company_lite_toggle_time_icon',array(
		'label'	=> __('Add Time Icon','it-company-lite'),
		'transport' => 'refresh',
		'section'	=> 'it_company_lite_post_settings',
		'setting'	=> 'it_company_lite_toggle_time_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'it_company_lite_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_toggle_time',array(
		'label' => esc_html__( 'Show / Hide Time','it-company-lite' ),
		'section' => 'it_company_lite_post_settings'
    )));

    $wp_customize->add_setting( 'it_company_lite_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'it_company_lite_switch_sanitization'
	));
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_featured_image_hide_show', array(
		'label' => esc_html__( 'Show / Hide Featured Image','it-company-lite' ),
		'section' => 'it_company_lite_post_settings'
    )));

    $wp_customize->add_setting( 'it_company_lite_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'it_company_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'it_company_lite_featured_image_border_radius', array(
		'label'       => esc_html__( 'Featured Image Border Radius','it-company-lite' ),
		'section'     => 'it_company_lite_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'it_company_lite_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'it_company_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'it_company_lite_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Featured Image Box Shadow','it-company-lite' ),
		'section'     => 'it_company_lite_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Featured Image
	$wp_customize->add_setting('it_company_lite_blog_post_featured_image_dimension',array(
       'default' => 'default',
       'sanitize_callback'	=> 'it_company_lite_sanitize_choices'
	));
  	$wp_customize->add_control('it_company_lite_blog_post_featured_image_dimension',array(
		'type' => 'select',
		'label'	=> __('Blog Post Featured Image Dimension','it-company-lite'),
		'section'	=> 'it_company_lite_post_settings',
		'choices' => array(
		'default' => __('Default','it-company-lite'),
		'custom' => __('Custom Image Size','it-company-lite'),
      ),
  	));

	$wp_customize->add_setting('it_company_lite_blog_post_featured_image_custom_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
		));
	$wp_customize->add_control('it_company_lite_blog_post_featured_image_custom_width',array(
		'label'	=> __('Featured Image Custom Width','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
    	'placeholder' => __( '10px', 'it-company-lite' ),),
		'section'=> 'it_company_lite_post_settings',
		'type'=> 'text',
		'active_callback' => 'it_company_lite_blog_post_featured_image_dimension'
		));

	$wp_customize->add_setting('it_company_lite_blog_post_featured_image_custom_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_blog_post_featured_image_custom_height',array(
		'label'	=> __('Featured Image Custom Height','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
    	'placeholder' => __( '10px', 'it-company-lite' ),),
		'section'=> 'it_company_lite_post_settings',
		'type'=> 'text',
		'active_callback' => 'it_company_lite_blog_post_featured_image_dimension'
	));

    $wp_customize->add_setting( 'it_company_lite_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'it_company_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'it_company_lite_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','it-company-lite' ),
		'section'     => 'it_company_lite_post_settings',
		'type'        => 'range',
		'settings'    => 'it_company_lite_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('it_company_lite_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','it-company-lite'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','it-company-lite'),
		'section'=> 'it_company_lite_post_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('it_company_lite_blog_page_posts_settings',array(
        'default' => 'Into Blocks',
        'transport' => 'refresh',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_blog_page_posts_settings',array(
        'type' => 'select',
        'label' => __('Display Blog Posts','it-company-lite'),
        'section' => 'it_company_lite_post_settings',
        'choices' => array(
        	'Into Blocks' => __('Into Blocks','it-company-lite'),
            'Without Blocks' => __('Without Blocks','it-company-lite')
        ),
	) );

    $wp_customize->add_setting('it_company_lite_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_excerpt_settings',array(
        'type' => 'select',
        'label' => __('Post Content','it-company-lite'),
        'section' => 'it_company_lite_post_settings',
        'choices' => array(
        	'Content' => __('Content','it-company-lite'),
            'Excerpt' => __('Excerpt','it-company-lite'),
            'No Content' => __('No Content','it-company-lite')
        ),
	) );

	$wp_customize->add_setting('it_company_lite_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_post_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'it_company_lite_blog_pagination_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_blog_pagination_hide_show',array(
      'label' => esc_html__( 'Show / Hide Blog Pagination','it-company-lite' ),
      'section' => 'it_company_lite_post_settings'
    )));

	$wp_customize->add_setting( 'it_company_lite_blog_pagination_type', array(
        'default'			=> 'blog-page-numbers',
        'sanitize_callback'	=> 'it_company_lite_sanitize_choices'
    ));
    $wp_customize->add_control( 'it_company_lite_blog_pagination_type', array(
        'section' => 'it_company_lite_post_settings',
        'type' => 'select',
        'label' => __( 'Blog Pagination', 'it-company-lite' ),
        'choices'		=> array(
            'blog-page-numbers'  => __( 'Numeric', 'it-company-lite' ),
            'next-prev' => __( 'Older Posts/Newer Posts', 'it-company-lite' ),
    )));

    // Button Settings
	$wp_customize->add_section( 'it_company_lite_button_settings', array(
		'title' => __( 'Button Settings', 'it-company-lite' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('it_company_lite_button_text', array( 
		'selector' => '.post-main-box .content-bttn a', 
		'render_callback' => 'it_company_lite_customize_partial_it_company_lite_button_text', 
	));

    $wp_customize->add_setting('it_company_lite_button_text',array(
		'default'=> esc_html__( 'Read More', 'it-company-lite' ),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_button_text',array(
		'label'	=> __('Add Button Text','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Read More', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_button_settings',
		'type'=> 'text'
	));

	// font size button
	$wp_customize->add_setting('it_company_lite_button_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_button_font_size',array(
		'label'	=> __('Button Font Size','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'it-company-lite' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'it_company_lite_button_settings',
	));

	$wp_customize->add_setting( 'it_company_lite_button_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'it_company_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'it_company_lite_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','it-company-lite' ),
		'section'     => 'it_company_lite_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('it_company_lite_button_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_button_padding_top_bottom',array(
		'label'	=> __('Padding Top Bottom','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_button_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_button_padding_left_right',array(
		'label'	=> __('Padding Left Right','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_button_letter_spacing',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_button_letter_spacing',array(
		'label'	=> __('Button Letter Spacing','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'it-company-lite' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'it_company_lite_button_settings',
	));

	// text trasform
	$wp_customize->add_setting('it_company_lite_button_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_button_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Button Text Transform','it-company-lite'),
		'choices' => array(
            'Uppercase' => __('Uppercase','it-company-lite'),
            'Capitalize' => __('Capitalize','it-company-lite'),
            'Lowercase' => __('Lowercase','it-company-lite'),
        ),
		'section'=> 'it_company_lite_button_settings',
	));

	// Related Post Settings
	$wp_customize->add_section( 'it_company_lite_related_posts_settings', array(
		'title' => __( 'Related Posts Settings', 'it-company-lite' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('it_company_lite_related_post_title', array( 
		'selector' => '.related-post h3', 
		'render_callback' => 'it_company_lite_customize_partial_it_company_lite_related_post_title', 
	));

    $wp_customize->add_setting( 'it_company_lite_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_related_post',array(
		'label' => esc_html__( 'Show / Hide Related Post','it-company-lite' ),
		'section' => 'it_company_lite_related_posts_settings'
    )));

    $wp_customize->add_setting('it_company_lite_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_related_post_title',array(
		'label'	=> __('Add Related Post Title','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Related Post', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('it_company_lite_related_posts_count',array(
		'default'=> '3',
		'sanitize_callback'	=> 'it_company_lite_sanitize_float'
	));
	$wp_customize->add_control('it_company_lite_related_posts_count',array(
		'label'	=> __('Add Related Post Count','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '3', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_related_posts_settings',
		'type'=> 'number'
	));

	$wp_customize->add_setting( 'it_company_lite_related_posts_excerpt_number', array(
		'default'              => 20,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'it_company_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'it_company_lite_related_posts_excerpt_number', array(
		'label'       => esc_html__( 'Related Posts Excerpt length','it-company-lite' ),
		'section'     => 'it_company_lite_related_posts_settings',
		'type'        => 'range',
		'settings'    => 'it_company_lite_related_posts_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	// Single Posts Settings
	$wp_customize->add_section( 'it_company_lite_single_blog_settings', array(
		'title' => __( 'Single Post Settings', 'it-company-lite' ),
		'panel' => 'blog_post_parent_panel',
	));

  	$wp_customize->add_setting('it_company_lite_single_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new IT_Company_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'it_company_lite_single_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','it-company-lite'),
		'transport' => 'refresh',
		'section'	=> 'it_company_lite_single_blog_settings',
		'setting'	=> 'it_company_lite_single_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'it_company_lite_single_postdate',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'it_company_lite_switch_sanitization'
	) );
	$wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_single_postdate',array(
	    'label' => esc_html__( 'Show / Hide Date','it-company-lite' ),
	   'section' => 'it_company_lite_single_blog_settings'
	)));

	$wp_customize->add_setting('it_company_lite_single_author_icon',array(
		'default'	=> 'far fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new IT_Company_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'it_company_lite_single_author_icon',array(
		'label'	=> __('Add Author Icon','it-company-lite'),
		'transport' => 'refresh',
		'section'	=> 'it_company_lite_single_blog_settings',
		'setting'	=> 'it_company_lite_single_author_icon',
		'type'		=> 'icon'
	)));


    $wp_customize->add_setting( 'it_company_lite_single_author',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'it_company_lite_switch_sanitization'
	) );
	$wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_single_author',array(
	    'label' => esc_html__( 'Show / Hide Author','it-company-lite' ),
	    'section' => 'it_company_lite_single_blog_settings'
	)));

   	$wp_customize->add_setting('it_company_lite_single_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new IT_Company_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'it_company_lite_single_comments_icon',array(
		'label'	=> __('Add Comments Icon','it-company-lite'),
		'transport' => 'refresh',
		'section'	=> 'it_company_lite_single_blog_settings',
		'setting'	=> 'it_company_lite_single_comments_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'it_company_lite_single_comments',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'it_company_lite_switch_sanitization'
	) );
	$wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_single_comments',array(
	    'label' => esc_html__( 'Show / Hide Comments','it-company-lite' ),
	    'section' => 'it_company_lite_single_blog_settings'
	)));

  	$wp_customize->add_setting('it_company_lite_single_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new IT_Company_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'it_company_lite_single_time_icon',array(
		'label'	=> __('Add Time Icon','it-company-lite'),
		'transport' => 'refresh',
		'section'	=> 'it_company_lite_single_blog_settings',
		'setting'	=> 'it_company_lite_single_time_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'it_company_lite_single_time',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'it_company_lite_switch_sanitization'
	) );
	$wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_single_time',array(
	    'label' => esc_html__( 'Show / Hide Time','it-company-lite' ),
	    'section' => 'it_company_lite_single_blog_settings'
	)));

	$wp_customize->add_setting( 'it_company_lite_single_post_breadcrumb',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_single_post_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Breadcrumb','it-company-lite' ),
		'section' => 'it_company_lite_single_blog_settings'
    )));

    // Single Posts Category
  	$wp_customize->add_setting( 'it_company_lite_single_post_category',array(
		'default' => true,
		'transport' => 'refresh',
		'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
  	$wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_single_post_category',array(
		'label' => esc_html__( 'Show / Hide Category','it-company-lite' ),
		'section' => 'it_company_lite_single_blog_settings'
    )));

	$wp_customize->add_setting( 'it_company_lite_toggle_tags',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'it_company_lite_switch_sanitization'
	));
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_toggle_tags', array(
		'label' => esc_html__( 'Show / Hide Tags','it-company-lite' ),
		'section' => 'it_company_lite_single_blog_settings'
    )));

	$wp_customize->add_setting( 'it_company_lite_single_blog_post_navigation_show_hide',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'it_company_lite_switch_sanitization'
	));
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_single_blog_post_navigation_show_hide', array(
		'label' => esc_html__( 'Show / Hide Post Navigation','it-company-lite' ),
		'section' => 'it_company_lite_single_blog_settings'
    )));

	//navigation text
	$wp_customize->add_setting('it_company_lite_single_blog_prev_navigation_text',array(
		'default'=> 'PREVIOUS',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_single_blog_prev_navigation_text',array(
		'label'	=> __('Post Navigation Text','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'PREVIOUS', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_single_blog_next_navigation_text',array(
		'default'=> 'NEXT',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_single_blog_next_navigation_text',array(
		'label'	=> __('Post Navigation Text','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'NEXT', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_single_blog_comment_title',array(
		'default'=> 'Leave a Reply',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('it_company_lite_single_blog_comment_title',array(
		'label'	=> __('Add Comment Title','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Leave a Reply', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_single_blog_comment_button_text',array(
		'default'=> 'Post Comment',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('it_company_lite_single_blog_comment_button_text',array(
		'label'	=> __('Add Comment Button Text','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Post Comment', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_single_blog_comment_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_single_blog_comment_width',array(
		'label'	=> __('Comment Form Width','it-company-lite'),
		'description'	=> __('Enter a value in %. Example:50%','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '100%', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_single_blog_settings',
		'type'=> 'text'
	));

	// Grid layout setting
	$wp_customize->add_section( 'it_company_lite_grid_layout_settings', array(
		'title' => __( 'Grid Layout Settings', 'it-company-lite' ),
		'panel' => 'blog_post_parent_panel',
	));

  	$wp_customize->add_setting('it_company_lite_grid_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new IT_Company_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'it_company_lite_grid_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','it-company-lite'),
		'transport' => 'refresh',
		'section'	=> 'it_company_lite_grid_layout_settings',
		'setting'	=> 'it_company_lite_grid_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'it_company_lite_grid_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_grid_postdate',array(
        'label' => esc_html__( 'Show / Hide Post Date','it-company-lite' ),
        'section' => 'it_company_lite_grid_layout_settings'
    )));

	$wp_customize->add_setting('it_company_lite_grid_author_icon',array(
		'default'	=> 'far fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new IT_Company_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'it_company_lite_grid_author_icon',array(
		'label'	=> __('Add Author Icon','it-company-lite'),
		'transport' => 'refresh',
		'section'	=> 'it_company_lite_grid_layout_settings',
		'setting'	=> 'it_company_lite_grid_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'it_company_lite_grid_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_grid_author',array(
		'label' => esc_html__( 'Show / Hide Author','it-company-lite' ),
		'section' => 'it_company_lite_grid_layout_settings'
    )));

   	$wp_customize->add_setting('it_company_lite_grid_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new IT_Company_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'it_company_lite_grid_comments_icon',array(
		'label'	=> __('Add Comments Icon','it-company-lite'),
		'transport' => 'refresh',
		'section'	=> 'it_company_lite_grid_layout_settings',
		'setting'	=> 'it_company_lite_grid_comments_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'it_company_lite_grid_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_grid_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','it-company-lite' ),
		'section' => 'it_company_lite_grid_layout_settings'
    )));

 	$wp_customize->add_setting('it_company_lite_grid_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_grid_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','it-company-lite'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','it-company-lite'),
		'section'=> 'it_company_lite_grid_layout_settings',
		'type'=> 'text'
	));  

  	$wp_customize->add_setting('it_company_lite_display_grid_posts_settings',array(
	    'default' => 'Into Blocks',
	    'transport' => 'refresh',
	    'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_display_grid_posts_settings',array(
	    'type' => 'select',
	    'label' => __('Display Grid Posts','it-company-lite'),
	    'section' => 'it_company_lite_grid_layout_settings',
	    'choices' => array(
	    	'Into Blocks' => __('Into Blocks','it-company-lite'),
	      'Without Blocks' => __('Without Blocks','it-company-lite')
	      ),
	) );

	$wp_customize->add_setting('it_company_lite_grid_button_text',array(
		'default'=> esc_html__('Read More','it-company-lite'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_grid_button_text',array(
		'label'	=> esc_html__('Add Button Text','it-company-lite'),
		'input_attrs' => array(
        'placeholder' => esc_html__( 'Read More', 'it-company-lite' ),
      ),
		'section'=> 'it_company_lite_grid_layout_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_grid_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_grid_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_grid_layout_settings',
		'type'=> 'text'
	));

 	// other settings
	$OtherParentPanel = new IT_Company_Lite_WP_Customize_Panel( $wp_customize, 'it_company_lite_other_panel_id', array(
		'title' => __( 'Others Settings', 'it-company-lite' ),
		'panel' => 'it_company_lite_panel_id',
	));

	$wp_customize->add_panel( $OtherParentPanel );

	$wp_customize->add_section( 'it_company_lite_left_right', array(
    	'title'      => esc_html__( 'General Settings', 'it-company-lite' ),
		'panel' => 'it_company_lite_other_panel_id'
	) );

	$wp_customize->add_setting('it_company_lite_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control(new IT_Company_Lite_Image_Radio_Control($wp_customize, 'it_company_lite_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','it-company-lite'),
        'description' => __('Here you can change the width layout of Website.','it-company-lite'),
        'section' => 'it_company_lite_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/assets/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/assets/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('it_company_lite_page_layout',array(
        'default' => 'One Column',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','it-company-lite'),
        'description' => __('Here you can change the sidebar layout for pages. ','it-company-lite'),
        'section' => 'it_company_lite_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','it-company-lite'),
            'Right Sidebar' => __('Right Sidebar','it-company-lite'),
            'One Column' => __('One Column','it-company-lite')
        ),
	) );

	$wp_customize->add_setting( 'it_company_lite_single_page_breadcrumb',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_single_page_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Page Breadcrumb','it-company-lite' ),
		'section' => 'it_company_lite_left_right'
    )));

	 //Wow Animation
	$wp_customize->add_setting( 'it_company_lite_animation',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_animation',array(
        'label' => esc_html__( 'Show / Hide Animation ','it-company-lite' ),
        'description' => __('Here you can disable overall site animation effect','it-company-lite'),
        'section' => 'it_company_lite_left_right'
    )));

    $wp_customize->add_setting('it_company_lite_reset_all_settings',array(
      'sanitize_callback'	=> 'sanitize_text_field',
   	));
   	$wp_customize->add_control(new IT_Company_Lite_Reset_Custom_Control($wp_customize, 'it_company_lite_reset_all_settings',array(
      'type' => 'reset_control',
      'label' => __('Reset All Settings', 'it-company-lite'),
      'description' => 'it_company_lite_reset_all_settings',
      'section' => 'it_company_lite_left_right'
   	)));

	//Pre-Loader
	$wp_customize->add_setting( 'it_company_lite_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_loader_enable',array(
        'label' => esc_html__( 'Show / Hide Pre-Loader','it-company-lite' ),
        'section' => 'it_company_lite_left_right'
    )));

	$wp_customize->add_setting('it_company_lite_preloader_bg_color', array(
		'default'           => '#927ae9',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'it_company_lite_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'it-company-lite'),
		'section'  => 'it_company_lite_left_right',
	)));

	$wp_customize->add_setting('it_company_lite_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'it_company_lite_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'it-company-lite'),
		'section'  => 'it_company_lite_left_right',
	)));

	$wp_customize->add_setting('it_company_lite_preloader_bg_img',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'it_company_lite_preloader_bg_img',array(
        'label' => __('Preloader Background Image','it-company-lite'),
        'section' => 'it_company_lite_left_right'
	)));

    //404 Page Setting
	$wp_customize->add_section('it_company_lite_404_page',array(
		'title'	=> __('404 Page Settings','it-company-lite'),
		'panel' => 'it_company_lite_other_panel_id',
	));	

	$wp_customize->add_setting('it_company_lite_404_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('it_company_lite_404_page_title',array(
		'label'	=> __('Add Title','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '404 Not Found', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_404_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('it_company_lite_404_page_content',array(
		'label'	=> __('Add Text','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_404_page_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_404_page_button_text',array(
		'label'	=> __('Add Button Text','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Return to the home page', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_404_page',
		'type'=> 'text'
	));

	//No Result Page Setting
	$wp_customize->add_section('it_company_lite_no_results_page',array(
		'title'	=> __('No Results Page Settings','it-company-lite'),
		'panel' => 'it_company_lite_other_panel_id',
	));	

	$wp_customize->add_setting('it_company_lite_no_results_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('it_company_lite_no_results_page_title',array(
		'label'	=> __('Add Title','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Nothing Found', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_no_results_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_no_results_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('it_company_lite_no_results_page_content',array(
		'label'	=> __('Add Text','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_no_results_page',
		'type'=> 'text'
	));

	//Social Icon Setting
	$wp_customize->add_section('it_company_lite_social_icon_settings',array(
		'title'	=> __('Social Icons Settings','it-company-lite'),
		'panel' => 'it_company_lite_other_panel_id',
	));	

	$wp_customize->add_setting('it_company_lite_social_icon_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_social_icon_font_size',array(
		'label'	=> __('Icon Font Size','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_social_icon_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_social_icon_padding',array(
		'label'	=> __('Icon Padding','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_social_icon_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_social_icon_width',array(
		'label'	=> __('Icon Width','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_social_icon_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_social_icon_height',array(
		'label'	=> __('Icon Height','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'it_company_lite_social_icon_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'it_company_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'it_company_lite_social_icon_border_radius', array(
		'label'       => esc_html__( 'Icon Border Radius','it-company-lite' ),
		'section'     => 'it_company_lite_social_icon_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Responsive Media Settings
	$wp_customize->add_section('it_company_lite_responsive_media',array(
		'title'	=> __('Responsive Media','it-company-lite'),
		'panel' => 'it_company_lite_other_panel_id',
	));

	$wp_customize->add_setting( 'it_company_lite_resp_topbar_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_resp_topbar_hide_show',array(
      'label' => esc_html__( 'Show / Hide Topbar','it-company-lite' ),
      'section' => 'it_company_lite_responsive_media'
    )));

    $wp_customize->add_setting( 'it_company_lite_stickyheader_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_stickyheader_hide_show',array(
      'label' => esc_html__( 'Sticky Header','it-company-lite' ),
      'section' => 'it_company_lite_responsive_media'
    )));

    $wp_customize->add_setting( 'it_company_lite_resp_slider_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_resp_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','it-company-lite' ),
      'section' => 'it_company_lite_responsive_media'
    )));

    $wp_customize->add_setting( 'it_company_lite_sidebar_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_sidebar_hide_show',array(
      'label' => esc_html__( 'Show / Hide Sidebar','it-company-lite' ),
      'section' => 'it_company_lite_responsive_media'
    )));

    $wp_customize->add_setting( 'it_company_lite_resp_scroll_top_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_resp_scroll_top_hide_show',array(
      'label' => esc_html__( 'Show / Hide Scroll To Top','it-company-lite' ),
      'section' => 'it_company_lite_responsive_media'
    )));

    $wp_customize->add_setting('it_company_lite_resp_menu_toggle_btn_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'it_company_lite_resp_menu_toggle_btn_bg_color', array(
		'label'    => __('Toggle Button Bg Color', 'it-company-lite'),
		'section'  => 'it_company_lite_responsive_media',
	)));

    $wp_customize->add_setting('it_company_lite_res_open_menus_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new IT_Company_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'it_company_lite_res_open_menus_icon',array(
		'label'	=> __('Add Open Menu Icon','it-company-lite'),
		'transport' => 'refresh',
		'section'	=> 'it_company_lite_responsive_media',
		'setting'	=> 'it_company_lite_res_open_menus_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('it_company_lite_res_close_menu_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new IT_Company_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'it_company_lite_res_close_menu_icon',array(
		'label'	=> __('Add Close Menu Icon','it-company-lite'),
		'transport' => 'refresh',
		'section'	=> 'it_company_lite_responsive_media',
		'setting'	=> 'it_company_lite_res_close_menu_icon',
		'type'		=> 'icon'
	)));

    //Woocommerce settings
	$wp_customize->add_section('it_company_lite_woocommerce_section', array(
		'title'    => __('WooCommerce Layout', 'it-company-lite'),
		'priority' => null,
		'panel'    => 'woocommerce',
	));

    //Shop Page Featured Image
	$wp_customize->add_setting( 'it_company_lite_shop_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'it_company_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'it_company_lite_shop_featured_image_border_radius', array(
		'label'       => esc_html__( 'Shop Page Featured Image Border Radius','it-company-lite' ),
		'section'     => 'it_company_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'it_company_lite_shop_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'it_company_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'it_company_lite_shop_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Shop Page Featured Image Box Shadow','it-company-lite' ),
		'section'     => 'it_company_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'it_company_lite_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product .sidebar', 
		'render_callback' => 'it_company_lite_customize_partial_it_company_lite_woocommerce_shop_page_sidebar', ) );

    //Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'it_company_lite_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Shop Page Sidebar','it-company-lite' ),
		'section' => 'it_company_lite_woocommerce_section'
    )));

    $wp_customize->add_setting('it_company_lite_shop_page_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_shop_page_layout',array(
        'type' => 'select',
        'label' => __('Shop Page Sidebar Layout','it-company-lite'),
        'section' => 'it_company_lite_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','it-company-lite'),
            'Right Sidebar' => __('Right Sidebar','it-company-lite'),
        ),
	) );

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'it_company_lite_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product .sidebar', 
		'render_callback' => 'it_company_lite_customize_partial_it_company_lite_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'it_company_lite_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Single Product Sidebar','it-company-lite' ),
		'section' => 'it_company_lite_woocommerce_section'
    )));

    $wp_customize->add_setting('it_company_lite_single_product_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_single_product_layout',array(
        'type' => 'select',
        'label' => __('Single Product Sidebar Layout','it-company-lite'),
        'section' => 'it_company_lite_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','it-company-lite'),
            'Right Sidebar' => __('Right Sidebar','it-company-lite'),
        ),
	) );
	
    //Products per page
    $wp_customize->add_setting('it_company_lite_products_per_page',array(
		'default'=> '9',
		'sanitize_callback'	=> 'it_company_lite_sanitize_float'
	));
	$wp_customize->add_control('it_company_lite_products_per_page',array(
		'label'	=> __('Products Per Page','it-company-lite'),
		'description' => __('Display on shop page','it-company-lite'),
		'input_attrs' => array(
            'step'             => 1,
			'min'              => 0,
			'max'              => 50,
        ),
		'section'=> 'it_company_lite_woocommerce_section',
		'type'=> 'number',
	));

    //Products per row
    $wp_customize->add_setting('it_company_lite_products_per_row',array(
		'default'=> '3',
		'sanitize_callback'	=> 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_products_per_row',array(
		'label'	=> __('Products Per Row','it-company-lite'),
		'description' => __('Display on shop page','it-company-lite'),
		'choices' => array(
            '2' => '2',
			'3' => '3',
			'4' => '4',
        ),
		'section'=> 'it_company_lite_woocommerce_section',
		'type'=> 'select',
	));

	//Products padding
	$wp_customize->add_setting('it_company_lite_products_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_products_padding_top_bottom',array(
		'label'	=> __('Products Padding Top Bottom','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_products_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_products_padding_left_right',array(
		'label'	=> __('Products Padding Left Right','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_woocommerce_section',
		'type'=> 'text'
	));

	//Products box shadow
	$wp_customize->add_setting( 'it_company_lite_products_box_shadow', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'it_company_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'it_company_lite_products_box_shadow', array(
		'label'       => esc_html__( 'Products Box Shadow','it-company-lite' ),
		'section'     => 'it_company_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Products border radius
    $wp_customize->add_setting( 'it_company_lite_products_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'it_company_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'it_company_lite_products_border_radius', array(
		'label'       => esc_html__( 'Products Border Radius','it-company-lite' ),
		'section'     => 'it_company_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('it_company_lite_products_btn_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_products_btn_padding_top_bottom',array(
		'label'	=> __('Products Button Padding Top Bottom','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('it_company_lite_products_btn_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_products_btn_padding_left_right',array(
		'label'	=> __('Products Button Padding Left Right','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'it_company_lite_products_button_border_radius', array(
		'default'              => '100',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'it_company_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'it_company_lite_products_button_border_radius', array(
		'label'       => esc_html__( 'Products Button Border Radius','it-company-lite' ),
		'section'     => 'it_company_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Products Sale Badge
	$wp_customize->add_setting('it_company_lite_woocommerce_sale_position',array(
        'default' => 'right',
        'sanitize_callback' => 'it_company_lite_sanitize_choices'
	));
	$wp_customize->add_control('it_company_lite_woocommerce_sale_position',array(
        'type' => 'select',
        'label' => __('Sale Badge Position','it-company-lite'),
        'section' => 'it_company_lite_woocommerce_section',
        'choices' => array(
            'left' => __('Left','it-company-lite'),
            'right' => __('Right','it-company-lite'),
        ),
	) );

	$wp_customize->add_setting('it_company_lite_woocommerce_sale_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('it_company_lite_woocommerce_sale_font_size',array(
		'label'	=> __('Sale Font Size','it-company-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','it-company-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'it-company-lite' ),
        ),
		'section'=> 'it_company_lite_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'it_company_lite_woocommerce_sale_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'it_company_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'it_company_lite_woocommerce_sale_border_radius', array(
		'label'       => esc_html__( 'Sale Border Radius','it-company-lite' ),
		'section'     => 'it_company_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	// Related Product
    $wp_customize->add_setting( 'it_company_lite_related_product_show_hide',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'it_company_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new IT_Company_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'it_company_lite_related_product_show_hide',array(
        'label' => esc_html__( 'Show / Hide Related product','it-company-lite' ),
        'section' => 'it_company_lite_woocommerce_section'
    )));

    // Has to be at the top
	$wp_customize->register_panel_type( 'IT_Company_Lite_WP_Customize_Panel' );
	$wp_customize->register_section_type( 'IT_Company_Lite_WP_Customize_Section' );
}

add_action( 'customize_register', 'it_company_lite_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

if ( class_exists( 'WP_Customize_Panel' ) ) {
  	class IT_Company_Lite_WP_Customize_Panel extends WP_Customize_Panel {
	    public $panel;
	    public $type = 'it_company_lite_panel';
	    public function json() {

	      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'type', 'panel', ) );
	      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
	      $array['content'] = $this->get_content();
	      $array['active'] = $this->active();
	      $array['instanceNumber'] = $this->instance_number;
	      return $array;
    	}
  	}
}

if ( class_exists( 'WP_Customize_Section' ) ) {
  	class IT_Company_Lite_WP_Customize_Section extends WP_Customize_Section {
	    public $section;
	    public $type = 'it_company_lite_section';
	    public function json() {

	      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'panel', 'type', 'description_hidden', 'section', ) );
	      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
	      $array['content'] = $this->get_content();
	      $array['active'] = $this->active();
	      $array['instanceNumber'] = $this->instance_number;

	      if ( $this->panel ) {
	        $array['customizeAction'] = sprintf( 'Customizing &#9656; %s', esc_html( $this->manager->get_panel( $this->panel )->title ) );
	      } else {
	        $array['customizeAction'] = 'Customizing';
	      }
	      return $array;
    	}
  	}
}

// Enqueue our scripts and styles
function it_company_lite_customize_controls_scripts() {
  wp_enqueue_script( 'customizer-controls', get_theme_file_uri( '/assets/js/customizer-controls.js' ), array(), '1.0', true );
}
add_action( 'customize_controls_enqueue_scripts', 'it_company_lite_customize_controls_scripts' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class IT_Company_Lite_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'IT_Company_Lite_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new IT_Company_Lite_Customize_Section_Pro($manager,'it_company_lite_upgrade_pro_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'IT COMPANY PRO', 'it-company-lite' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'it-company-lite' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/it-company-wordpress-theme/'),
		)));

		$manager->add_section(new IT_Company_Lite_Customize_Section_Pro($manager,'it_company_lite_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'it-company-lite' ),
			'pro_text' => esc_html__( 'DOCS', 'it-company-lite' ),
			'pro_url'  => esc_url('https://preview.vwthemesdemo.com/docs/free-vw-it-company/'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'it-company-lite-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'it-company-lite-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );

		wp_localize_script(
		'it-company-lite-customize-controls',
		'it_company_lite_customizer_params',
		array(
			'ajaxurl' =>	admin_url( 'admin-ajax.php' )
		));
	}
}

// Doing this customizer thang!
IT_Company_Lite_Customize::get_instance();